# jTWA.spin1

``jTWA.spin1`` comprises all functionality that is specific to systems with spin-1.


## jTWA.spin1.hamiltonian
```{eval-rst}
.. autofunction:: jTWA.spin1.hamiltonian.hamiltonian
```

```{eval-rst}
.. autofunction:: jTWA.spin1.hamiltonian.hamiltonian_singleWell
```

```{eval-rst}
.. autofunction:: jTWA.spin1.hamiltonian.update_cfg
```

## jTWA.spin1.initState
```{eval-rst}
.. autofunction:: jTWA.spin1.initState.getPolarState

```

## jTWA.spin1.observables
```{eval-rst}
.. autofunction:: jTWA.spin1.observables.get_spin_operators
```

```{eval-rst}
.. autofunction:: jTWA.spin1.observables.compute_observables
```

```{eval-rst}
.. autofunction:: jTWA.spin1.observables.compute_spin_observables
```

```{eval-rst}
.. autofunction:: jTWA.spin1.observables.compute_mode_occupations
```

```{eval-rst}
.. autofunction:: jTWA.spin1.observables.beamsplit
```